@@ -61,6 +61,7 @@ struct _PhotosBaseItemPrivate
 {
   cairo_surface_t *surface;
   GAppInfo *default_app;
+  GCancellable *cancellable;
   GdkPixbuf *original_icon;
   GeglNode *buffer_sink;
   GeglNode *buffer_source;
@@ -477,7 +478,7 @@ photos_base_item_default_update_type_description (PhotosBaseItem *self)
   else if (priv->mime_type != NULL)
     description = g_content_type_get_description (priv->mime_type);
 
-  photos_utils_take_string (&priv->type_description, description);
+  priv->type_description = description;
 }
 
 
@@ -571,8 +572,8 @@ photos_base_item_set_failed_icon (PhotosBaseItem *self)
 static void
 photos_base_item_refresh_thumb_path_pixbuf (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
-  PhotosBaseItem *self = PHOTOS_BASE_ITEM (user_data);
-  PhotosBaseItemPrivate *priv = self->priv;
+  PhotosBaseItem *self;
+  PhotosBaseItemPrivate *priv;
   GApplication *app;
   GdkPixbuf *pixbuf = NULL;
   GdkPixbuf *scaled_pixbuf = NULL;
@@ -584,18 +585,33 @@ photos_base_item_refresh_thumb_path_pixbuf (GObject *source_object, GAsyncResult
   pixbuf = gdk_pixbuf_new_from_stream_finish (res, &error);
   if (error != NULL)
     {
-      GFile *file;
-      gchar *uri;
+      if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
+        {
+          g_error_free (error);
+          goto out;
+        }
+      else
+        {
+          GFile *file;
+          gchar *uri;
 
-      file = G_FILE (g_object_get_data (G_OBJECT (stream), "file"));
-      uri = g_file_get_uri (file);
-      g_warning ("Unable to create pixbuf from %s: %s", uri, error->message);
+          file = G_FILE (g_object_get_data (G_OBJECT (stream), "file"));
+          uri = g_file_get_uri (file);
+          g_warning ("Unable to create pixbuf from %s: %s", uri, error->message);
+          g_file_delete_async (file, G_PRIORITY_DEFAULT, NULL, NULL, NULL);
+          g_free (uri);
+          g_error_free (error);
+        }
+    }
+
+  self = PHOTOS_BASE_ITEM (user_data);
+  priv = self->priv;
+
+  if (pixbuf == NULL)
+    {
       priv->failed_thumbnailing = TRUE;
       g_clear_pointer (&priv->thumb_path, g_free);
-      g_file_delete_async (file, G_PRIORITY_DEFAULT, NULL, NULL, NULL);
       photos_base_item_set_failed_icon (self);
-      g_free (uri);
-      g_error_free (error);
       goto out;
     }
 
@@ -609,44 +625,56 @@ photos_base_item_refresh_thumb_path_pixbuf (GObject *source_object, GAsyncResult
   g_input_stream_close_async (stream, G_PRIORITY_DEFAULT, NULL, NULL, NULL);
   g_clear_object (&scaled_pixbuf);
   g_clear_object (&pixbuf);
-  g_object_unref (self);
 }
 
 
 static void
 photos_base_item_refresh_thumb_path_read (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
-  PhotosBaseItem *self = PHOTOS_BASE_ITEM (user_data);
-  PhotosBaseItemPrivate *priv = self->priv;
+  PhotosBaseItem *self;
+  PhotosBaseItemPrivate *priv;
   GError *error = NULL;
   GFile *file = G_FILE (source_object);
-  GFileInputStream *stream;
+  GFileInputStream *stream = NULL;
 
   stream = g_file_read_finish (file, res, &error);
   if (error != NULL)
     {
-      gchar *uri;
+      if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
+	{
+	  g_error_free (error);
+	  goto out;
+	}
+      else
+	{
+	  gchar *uri;
 
-      uri = g_file_get_uri (file);
-      g_warning ("Unable to read file at %s: %s", uri, error->message);
+	  uri = g_file_get_uri (file);
+	  g_warning ("Unable to read file at %s: %s", uri, error->message);
+	  g_file_delete_async (file, G_PRIORITY_DEFAULT, NULL, NULL, NULL);
+	  g_free (uri);
+	  g_error_free (error);
+	}
+    }
+
+  self = PHOTOS_BASE_ITEM (user_data);
+  priv = self->priv;
+
+  if (stream == NULL)
+    {
       priv->failed_thumbnailing = TRUE;
       g_clear_pointer (&priv->thumb_path, g_free);
-      g_file_delete_async (file, G_PRIORITY_DEFAULT, NULL, NULL, NULL);
       photos_base_item_set_failed_icon (self);
-      g_free (uri);
-      g_error_free (error);
       goto out;
     }
 
   g_object_set_data_full (G_OBJECT (stream), "file", g_object_ref (file), g_object_unref);
   gdk_pixbuf_new_from_stream_async (G_INPUT_STREAM (stream),
-                                    NULL,
+                                    priv->cancellable,
                                     photos_base_item_refresh_thumb_path_pixbuf,
-                                    g_object_ref (self));
-  g_object_unref (stream);
-
+                                    self);
  out:
-  g_object_unref (self);
+  g_clear_object (&stream);
 }
 
 
@@ -659,9 +687,9 @@ photos_base_item_refresh_thumb_path (PhotosBaseItem *self)
   thumb_file = g_file_new_for_path (priv->thumb_path);
   g_file_read_async (thumb_file,
                      G_PRIORITY_DEFAULT,
-                     NULL,
+                     priv->cancellable,
                      photos_base_item_refresh_thumb_path_read,
-                     g_object_ref (self));
+                     self);
   g_object_unref (thumb_file);
 }
 
@@ -669,21 +697,40 @@ photos_base_item_refresh_thumb_path (PhotosBaseItem *self)
 static void
 photos_base_item_thumbnail_path_info (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
-  PhotosBaseItem *self = PHOTOS_BASE_ITEM (user_data);
-  PhotosBaseItemPrivate *priv = self->priv;
+  PhotosBaseItem *self;
+  PhotosBaseItemPrivate *priv;
   GError *error = NULL;
   GFile *file = G_FILE (source_object);
   GFileInfo *info = NULL;
 
-  g_clear_pointer (&priv->thumb_path, g_free);
-
   info = g_file_query_info_finish (file, res, &error);
   if (error != NULL)
     {
-      g_warning ("Unable to query info for file at %s: %s", priv->uri, error->message);
+      if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
+        {
+          g_error_free (error);
+          goto out;
+        }
+      else
+        {
+          gchar *uri;
+
+          uri = g_file_get_uri (file);
+          g_warning ("Unable to query info for file at %s: %s", uri, error->message);
+          g_free (uri);
+          g_error_free (error);
+        }
+    }
+
+  self = PHOTOS_BASE_ITEM (user_data);
+  priv = self->priv;
+
+  g_clear_pointer (&priv->thumb_path, g_free);
+
+  if (info == NULL)
+    {
       priv->failed_thumbnailing = TRUE;
       photos_base_item_set_failed_icon (self);
-      g_error_free (error);
       goto out;
     }
 
@@ -700,7 +747,6 @@ photos_base_item_thumbnail_path_info (GObject *source_object, GAsyncResult *res,
 
  out:
   g_clear_object (&info);
-  g_object_unref (self);
 }
 
 
@@ -727,9 +773,9 @@ photos_base_item_create_thumbnail_cb (GObject *source_object, GAsyncResult *res,
                            G_FILE_ATTRIBUTE_THUMBNAIL_PATH,
                            G_FILE_QUERY_INFO_NONE,
                            G_PRIORITY_DEFAULT,
-                           NULL,
+                           priv->cancellable,
                            photos_base_item_thumbnail_path_info,
-                           g_object_ref (self));
+                           self);
 
  out:
   g_object_unref (file);
@@ -739,21 +785,40 @@ photos_base_item_create_thumbnail_cb (GObject *source_object, GAsyncResult *res,
 static void
 photos_base_item_file_query_info (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
-  PhotosBaseItem *self = PHOTOS_BASE_ITEM (user_data);
-  PhotosBaseItemPrivate *priv = self->priv;
+  PhotosBaseItem *self;
+  PhotosBaseItemPrivate *priv;
   GError *error = NULL;
   GFile *file = G_FILE (source_object);
   GFileInfo *info = NULL;
 
-  g_clear_pointer (&priv->thumb_path, g_free);
-
   info = g_file_query_info_finish (file, res, &error);
   if (error != NULL)
     {
-      g_warning ("Unable to query info for file at %s: %s", priv->uri, error->message);
+      if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
+	{
+	  g_error_free (error);
+	  goto out;
+	}
+      else
+	{
+	  gchar *uri;
+
+	  uri = g_file_get_uri (file);
+	  g_warning ("Unable to query info for file at %s: %s", uri, error->message);
+	  g_free (uri);
+	  g_error_free (error);
+	}
+    }
+
+  self = PHOTOS_BASE_ITEM (user_data);
+  priv = self->priv;
+
+  g_clear_pointer (&priv->thumb_path, g_free);
+
+  if (info == NULL)
+    {
       priv->failed_thumbnailing = TRUE;
       photos_base_item_set_failed_icon (self);
-      g_error_free (error);
       goto out;
     }
 
@@ -770,7 +835,6 @@ photos_base_item_file_query_info (GObject *source_object, GAsyncResult *res, gpo
 
  out:
   g_clear_object (&info);
-  g_object_unref (self);
 }
 
 
@@ -1277,20 +1341,14 @@ photos_base_item_save_buffer_zoom (GObject *source_object, GAsyncResult *res, gp
 {
   GTask *task = G_TASK (user_data);
   PhotosBaseItem *self;
-  PhotosBaseItemPrivate *priv;
   GCancellable *cancellable;
   GError *error;
   GFile *file = NULL;
   GeglBuffer *buffer = GEGL_BUFFER (source_object);
   GeglBuffer *buffer_zoomed = NULL;
   PhotosBaseItemSaveData *data;
-  const gchar *extension;
-  gchar *basename = NULL;
-  gchar *filename = NULL;
 
   self = PHOTOS_BASE_ITEM (g_task_get_source_object (task));
-  priv = self->priv;
-
   cancellable = g_task_get_cancellable (task);
   data = (PhotosBaseItemSaveData *) g_task_get_task_data (task);
 
@@ -1305,11 +1363,7 @@ photos_base_item_save_buffer_zoom (GObject *source_object, GAsyncResult *res, gp
   g_assert_null (data->buffer);
   data->buffer = g_object_ref (buffer_zoomed);
 
-  basename = photos_utils_filename_strip_extension (priv->filename);
-  extension = g_strcmp0 (priv->mime_type, "image/png") == 0 ? ".png" : ".jpg";
-  filename = g_strconcat (basename, extension, NULL);
-
-  file = g_file_get_child (data->dir, filename);
+  file = g_file_get_child (data->dir, self->priv->filename);
   photos_utils_file_create_async (file,
                                   G_FILE_CREATE_NONE,
                                   G_PRIORITY_DEFAULT,
@@ -1318,8 +1372,6 @@ photos_base_item_save_buffer_zoom (GObject *source_object, GAsyncResult *res, gp
                                   g_object_ref (task));
 
  out:
-  g_free (basename);
-  g_free (filename);
   g_clear_object (&buffer_zoomed);
   g_clear_object (&file);
   g_object_unref (task);
@@ -1364,9 +1416,9 @@ photos_base_item_refresh_icon (PhotosBaseItem *self)
                            G_FILE_ATTRIBUTE_THUMBNAIL_PATH,
                            G_FILE_QUERY_INFO_NONE,
                            G_PRIORITY_DEFAULT,
-                           NULL,
+                           priv->cancellable,
                            photos_base_item_file_query_info,
-                           g_object_ref (self));
+                           self);
   g_object_unref (file);
 }
 
@@ -1388,40 +1440,23 @@ photos_base_item_populate_from_cursor (PhotosBaseItem *self, TrackerSparqlCursor
 {
   PhotosBaseItemPrivate *priv = self->priv;
   GTimeVal timeval;
-  const gchar *author;
+  gboolean favorite;
   const gchar *date_created;
   const gchar *equipment;
   const gchar *flash;
-  const gchar *id;
-  const gchar *identifier;
-  const gchar *mime_type;
   const gchar *mtime;
   const gchar *orientation;
-  const gchar *rdf_type;
-  const gchar *resource_urn;
   const gchar *title;
   const gchar *uri;
-  gchar *filename;
-  gchar *name_fallback;
 
   uri = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_URI, NULL);
-  if (uri == NULL)
-    uri = "";
-  photos_utils_set_string (&priv->uri, uri);
+  priv->uri = g_strdup ((uri == NULL) ? "" : uri);
 
-  id = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_URN, NULL);
-  photos_utils_set_string (&priv->id, id);
-
-  identifier = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_IDENTIFIER, NULL);
-  photos_utils_set_string (&priv->identifier, identifier);
-
-  author = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_AUTHOR, NULL);
-  photos_utils_set_string (&priv->author, author);
-
-  resource_urn = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_RESOURCE_URN, NULL);
-  photos_utils_set_string (&priv->resource_urn, resource_urn);
-
-  priv->favorite = tracker_sparql_cursor_get_boolean (cursor, PHOTOS_QUERY_COLUMNS_RESOURCE_FAVORITE);
+  priv->id = g_strdup (tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_URN, NULL));
+  priv->identifier = g_strdup (tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_IDENTIFIER, NULL));
+  priv->author = g_strdup (tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_AUTHOR, NULL));
+  priv->resource_urn = g_strdup (tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_RESOURCE_URN, NULL));
+  favorite = tracker_sparql_cursor_get_boolean (cursor, PHOTOS_QUERY_COLUMNS_RESOURCE_FAVORITE);
 
   mtime = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_MTIME, NULL);
   if (mtime != NULL)
@@ -1432,14 +1467,12 @@ photos_base_item_populate_from_cursor (PhotosBaseItem *self, TrackerSparqlCursor
   else
     priv->mtime = g_get_real_time () / 1000000;
 
-  mime_type = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_MIME_TYPE, NULL);
-  photos_utils_set_string (&priv->mime_type, mime_type);
-
-  rdf_type = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_RDF_TYPE, NULL);
-  photos_utils_set_string (&priv->rdf_type, rdf_type);
-
+  priv->mime_type = g_strdup (tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_MIME_TYPE, NULL));
+  priv->rdf_type = g_strdup (tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_RDF_TYPE, NULL));
   photos_base_item_update_info_from_type (self);
 
+  priv->favorite = favorite && !priv->collection;
+
   date_created = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_DATE_CREATED, NULL);
   if (date_created != NULL)
     {
@@ -1456,12 +1489,9 @@ photos_base_item_populate_from_cursor (PhotosBaseItem *self, TrackerSparqlCursor
 
   if (title == NULL)
     title = "";
-  photos_utils_set_string (&priv->name, title);
+  priv->name = g_strdup (title);
 
-  filename = g_strdup (tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_FILENAME, NULL));
-  if ((filename == NULL || filename[0] == '\0') && !priv->collection)
-    filename = PHOTOS_BASE_ITEM_GET_CLASS (self)->create_filename_fallback (self);
-  photos_utils_take_string (&priv->filename, filename);
+  priv->filename = g_strdup (tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_FILENAME, NULL));
 
   priv->width = tracker_sparql_cursor_get_integer (cursor, PHOTOS_QUERY_COLUMNS_WIDTH);
   priv->height = tracker_sparql_cursor_get_integer (cursor, PHOTOS_QUERY_COLUMNS_HEIGHT);
@@ -1480,9 +1510,7 @@ photos_base_item_populate_from_cursor (PhotosBaseItem *self, TrackerSparqlCursor
   flash = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_FLASH, NULL);
   priv->flash = g_quark_from_string (flash);
 
-  name_fallback = PHOTOS_BASE_ITEM_GET_CLASS (self)->create_name_fallback (self);
-  photos_utils_take_string (&priv->name_fallback, name_fallback);
-
+  priv->name_fallback = PHOTOS_BASE_ITEM_GET_CLASS (self)->create_name_fallback (self);
   photos_base_item_refresh_icon (self);
 }
 
@@ -1491,21 +1519,27 @@ static void
 photos_base_item_print_load (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
   PhotosBaseItem *self = PHOTOS_BASE_ITEM (source_object);
-  GError *error = NULL;
+  GError *error;
   GtkWindow *toplevel = GTK_WINDOW (user_data);
   GeglNode *node;
   GtkPrintOperation *print_op = NULL;
   GtkPrintOperationResult print_res;
 
-  node = photos_base_item_load_finish (self, res, NULL);
-  if (node == NULL)
-    goto out;
+  error = NULL;
+  node = photos_base_item_load_finish (self, res, &error);
+  if (error != NULL)
+    {
+      g_warning ("Unable to load the item: %s", error->message);
+      g_error_free (error);
+      goto out;
+    }
 
   print_op = photos_print_operation_new (self, node);
 
   /* It is self managing. */
   photos_print_notification_new (print_op);
 
+  error = NULL;
   print_res = gtk_print_operation_run (print_op, GTK_PRINT_OPERATION_ACTION_PRINT_DIALOG, toplevel, &error);
   if (print_res == GTK_PRINT_OPERATION_RESULT_APPLY)
     {
@@ -1543,6 +1577,12 @@ photos_base_item_dispose (GObject *object)
   PhotosBaseItem *self = PHOTOS_BASE_ITEM (object);
   PhotosBaseItemPrivate *priv = self->priv;
 
+  if (priv->cancellable != NULL)
+    {
+       g_cancellable_cancel (priv->cancellable);
+       g_clear_object (&priv->cancellable);
+    }
+
   g_clear_pointer (&priv->surface, (GDestroyNotify) cairo_surface_destroy);
   g_clear_object (&priv->default_app);
   g_clear_object (&priv->edit_graph);
@@ -1634,6 +1674,8 @@ photos_base_item_init (PhotosBaseItem *self)
   self->priv = photos_base_item_get_instance_private (self);
   priv = self->priv;
 
+  priv->cancellable = g_cancellable_new ();
+
   g_mutex_init (&priv->mutex_download);
   g_mutex_init (&priv->mutex);
 
@@ -1710,14 +1752,23 @@ photos_base_item_filterable_iface_init (PhotosFilterableInterface *iface)
 gboolean
 photos_base_item_can_edit (PhotosBaseItem *self)
 {
+  PhotosBaseItemPrivate *priv;
+
   g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), FALSE);
-  return PHOTOS_BASE_ITEM_GET_CLASS (self)->create_pipeline_path != NULL;
+  priv = self->priv;
+
+  g_return_val_if_fail (!priv->collection, FALSE);
+
+  return PHOTOS_BASE_ITEM_GET_CLASS (self)->create_pipeline_path != NULL
+    && priv->filename != NULL
+    && priv->filename[0] != '\0';
 }
 
 
 gboolean
 photos_base_item_can_trash (PhotosBaseItem *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), FALSE);
   return PHOTOS_BASE_ITEM_GET_CLASS (self)->trash != NULL;
 }
 
@@ -1730,7 +1781,7 @@ photos_base_item_create_preview (PhotosBaseItem *self,
                                  const gchar *first_property_name,
                                  ...)
 {
-  PhotosBaseItemPrivate *priv = self->priv;
+  PhotosBaseItemPrivate *priv;
   const Babl *format;
   GeglBuffer *buffer_orig = NULL;
   GeglBuffer *buffer = NULL;
@@ -1756,6 +1807,10 @@ photos_base_item_create_preview (PhotosBaseItem *self,
   guchar *buf = NULL;
   va_list ap;
 
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), NULL);
+  priv = self->priv;
+
+  g_return_val_if_fail (!priv->collection, NULL);
   g_return_val_if_fail (operation != NULL && operation[0] != '\0', NULL);
   g_return_val_if_fail (priv->buffer_source != NULL, NULL);
   g_return_val_if_fail (priv->edit_graph != NULL, NULL);
@@ -1835,6 +1890,7 @@ photos_base_item_create_preview (PhotosBaseItem *self,
 void
 photos_base_item_destroy (PhotosBaseItem *self)
 {
+  g_return_if_fail (PHOTOS_IS_BASE_ITEM (self));
   /* TODO: SearchCategoryManager */
   g_clear_object (&self->priv->watcher);
 }
@@ -1843,6 +1899,7 @@ photos_base_item_destroy (PhotosBaseItem *self)
 gchar *
 photos_base_item_download (PhotosBaseItem *self, GCancellable *cancellable, GError **error)
 {
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), NULL);
   return PHOTOS_BASE_ITEM_GET_CLASS (self)->download (self, cancellable, error);
 }
 
@@ -1855,6 +1912,8 @@ photos_base_item_download_async (PhotosBaseItem *self,
 {
   GTask *task;
 
+  g_return_if_fail (PHOTOS_IS_BASE_ITEM (self));
+
   task = g_task_new (self, cancellable, callback, user_data);
   g_task_set_source_tag (task, photos_base_item_download_async);
 
@@ -1868,6 +1927,7 @@ photos_base_item_download_finish (PhotosBaseItem *self, GAsyncResult *res, GErro
 {
   GTask *task = G_TASK (res);
 
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), NULL);
   g_return_val_if_fail (g_task_is_valid (res, self), NULL);
   g_return_val_if_fail (g_task_get_source_tag (task) == photos_base_item_download_async, NULL);
   g_return_val_if_fail (error == NULL || *error == NULL, NULL);
@@ -1879,6 +1939,7 @@ photos_base_item_download_finish (PhotosBaseItem *self, GAsyncResult *res, GErro
 const gchar *
 photos_base_item_get_author (PhotosBaseItem *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), NULL);
   return self->priv->author;
 }
 
@@ -1893,6 +1954,7 @@ photos_base_item_get_bbox_edited (PhotosBaseItem *self, GeglRectangle *out_bbox)
   g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), FALSE);
   priv = self->priv;
 
+  g_return_val_if_fail (!priv->collection, FALSE);
   g_return_val_if_fail (priv->edit_graph != NULL, FALSE);
   g_return_val_if_fail (priv->load_graph != NULL, FALSE);
   g_return_val_if_fail (priv->pipeline != NULL, FALSE);
@@ -1912,9 +1974,14 @@ photos_base_item_get_bbox_edited (PhotosBaseItem *self, GeglRectangle *out_bbox)
 gboolean
 photos_base_item_get_bbox_source (PhotosBaseItem *self, GeglRectangle *bbox)
 {
-  PhotosBaseItemPrivate *priv = self->priv;
+  PhotosBaseItemPrivate *priv;
   gboolean ret_val = FALSE;
 
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), FALSE);
+  priv = self->priv;
+
+  g_return_val_if_fail (!priv->collection, FALSE);
+
   if (priv->buffer_source == NULL)
     goto out;
 
@@ -1929,6 +1996,7 @@ photos_base_item_get_bbox_source (PhotosBaseItem *self, GeglRectangle *bbox)
 gint64
 photos_base_item_get_date_created (PhotosBaseItem *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), 0);
   return self->priv->date_created;
 }
 
@@ -1936,6 +2004,7 @@ photos_base_item_get_date_created (PhotosBaseItem *self)
 const gchar *
 photos_base_item_get_default_app_name (PhotosBaseItem *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), NULL);
   return self->priv->default_app_name;
 }
 
@@ -1943,6 +2012,7 @@ photos_base_item_get_default_app_name (PhotosBaseItem *self)
 GQuark
 photos_base_item_get_equipment (PhotosBaseItem *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), 0);
   return self->priv->equipment;
 }
 
@@ -1950,6 +2020,7 @@ photos_base_item_get_equipment (PhotosBaseItem *self)
 gdouble
 photos_base_item_get_exposure_time (PhotosBaseItem *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), 0.0);
   return self->priv->exposure_time;
 }
 
@@ -1957,6 +2028,7 @@ photos_base_item_get_exposure_time (PhotosBaseItem *self)
 GQuark
 photos_base_item_get_flash (PhotosBaseItem *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), 0);
   return self->priv->flash;
 }
 
@@ -1964,6 +2036,7 @@ photos_base_item_get_flash (PhotosBaseItem *self)
 const gchar *
 photos_base_item_get_filename (PhotosBaseItem *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), NULL);
   return self->priv->filename;
 }
 
@@ -1971,6 +2044,7 @@ photos_base_item_get_filename (PhotosBaseItem *self)
 gdouble
 photos_base_item_get_fnumber (PhotosBaseItem *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), 0.0);
   return self->priv->fnumber;
 }
 
@@ -1978,6 +2052,7 @@ photos_base_item_get_fnumber (PhotosBaseItem *self)
 gdouble
 photos_base_item_get_focal_length (PhotosBaseItem *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), 0.0);
   return self->priv->focal_length;
 }
 
@@ -1985,6 +2060,7 @@ photos_base_item_get_focal_length (PhotosBaseItem *self)
 gint64
 photos_base_item_get_height (PhotosBaseItem *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), 0);
   return self->priv->height;
 }
 
@@ -1992,6 +2068,7 @@ photos_base_item_get_height (PhotosBaseItem *self)
 const gchar *
 photos_base_item_get_identifier (PhotosBaseItem *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), NULL);
   return self->priv->identifier;
 }
 
@@ -1999,6 +2076,7 @@ photos_base_item_get_identifier (PhotosBaseItem *self)
 gdouble
 photos_base_item_get_iso_speed (PhotosBaseItem *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), 0.0);
   return self->priv->iso_speed;
 }
 
@@ -2006,6 +2084,7 @@ photos_base_item_get_iso_speed (PhotosBaseItem *self)
 const gchar *
 photos_base_item_get_mime_type (PhotosBaseItem *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), NULL);
   return self->priv->mime_type;
 }
 
@@ -2013,6 +2092,7 @@ photos_base_item_get_mime_type (PhotosBaseItem *self)
 gint64
 photos_base_item_get_mtime (PhotosBaseItem *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), 0);
   return self->priv->mtime;
 }
 
@@ -2020,6 +2100,7 @@ photos_base_item_get_mtime (PhotosBaseItem *self)
 const gchar *
 photos_base_item_get_name (PhotosBaseItem *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), NULL);
   return self->priv->name;
 }
 
@@ -2027,9 +2108,12 @@ photos_base_item_get_name (PhotosBaseItem *self)
 const gchar *
 photos_base_item_get_name_with_fallback (PhotosBaseItem *self)
 {
-  PhotosBaseItemPrivate *priv = self->priv;
+  PhotosBaseItemPrivate *priv;
   const gchar *name;
 
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), NULL);
+  priv = self->priv;
+
   name = priv->name;
   if (name == NULL || name[0] == '\0')
     name = priv->name_fallback;
@@ -2041,6 +2125,7 @@ photos_base_item_get_name_with_fallback (PhotosBaseItem *self)
 GdkPixbuf *
 photos_base_item_get_original_icon (PhotosBaseItem *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), NULL);
   return self->priv->original_icon;
 }
 
@@ -2048,6 +2133,7 @@ photos_base_item_get_original_icon (PhotosBaseItem *self)
 const gchar *
 photos_base_item_get_resource_urn (PhotosBaseItem *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), NULL);
   return self->priv->resource_urn;
 }
 
@@ -2055,6 +2141,7 @@ photos_base_item_get_resource_urn (PhotosBaseItem *self)
 GtkWidget *
 photos_base_item_get_source_widget (PhotosBaseItem *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), NULL);
   return PHOTOS_BASE_ITEM_GET_CLASS (self)->get_source_widget(self);
 }
 
@@ -2062,6 +2149,7 @@ photos_base_item_get_source_widget (PhotosBaseItem *self)
 cairo_surface_t *
 photos_base_item_get_surface (PhotosBaseItem *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), NULL);
   return self->priv->surface;
 }
 
@@ -2069,6 +2157,7 @@ photos_base_item_get_surface (PhotosBaseItem *self)
 const gchar *
 photos_base_item_get_type_description (PhotosBaseItem *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), NULL);
   return self->priv->type_description;
 }
 
@@ -2076,6 +2165,7 @@ photos_base_item_get_type_description (PhotosBaseItem *self)
 const gchar *
 photos_base_item_get_uri (PhotosBaseItem *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), NULL);
   return self->priv->uri;
 }
 
@@ -2083,9 +2173,12 @@ photos_base_item_get_uri (PhotosBaseItem *self)
 gchar *
 photos_base_item_get_where (PhotosBaseItem *self)
 {
-  PhotosBaseItemPrivate *priv = self->priv;
+  PhotosBaseItemPrivate *priv;
   gchar *ret_val;
 
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), NULL);
+  priv = self->priv;
+
   if (priv->collection)
     ret_val = g_strconcat ("{ ?urn nie:isPartOf <", priv->id, "> }", NULL);
   else
@@ -2098,6 +2191,7 @@ photos_base_item_get_where (PhotosBaseItem *self)
 gint64
 photos_base_item_get_width (PhotosBaseItem *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), 0);
   return self->priv->width;
 }
 
@@ -2105,6 +2199,7 @@ photos_base_item_get_width (PhotosBaseItem *self)
 gboolean
 photos_base_item_is_collection (PhotosBaseItem *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), FALSE);
   return self->priv->collection;
 }
 
@@ -2112,6 +2207,7 @@ photos_base_item_is_collection (PhotosBaseItem *self)
 gboolean
 photos_base_item_is_favorite (PhotosBaseItem *self)
 {
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), FALSE);
   return self->priv->favorite;
 }
 
@@ -2128,6 +2224,7 @@ photos_base_item_load_async (PhotosBaseItem *self,
   g_return_if_fail (PHOTOS_IS_BASE_ITEM (self));
   priv = self->priv;
 
+  g_return_if_fail (!priv->collection);
   g_return_if_fail (priv->edit_graph == NULL || priv->pipeline != NULL);
 
   task = g_task_new (self, cancellable, callback, user_data);
@@ -2174,6 +2271,7 @@ photos_base_item_load_finish (PhotosBaseItem *self, GAsyncResult *res, GError **
 {
   GTask *task = G_TASK (res);
 
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), NULL);
   g_return_val_if_fail (g_task_is_valid (res, self), NULL);
   g_return_val_if_fail (g_task_get_source_tag (task) == photos_base_item_load_async, NULL);
   g_return_val_if_fail (error == NULL || *error == NULL, NULL);
@@ -2185,6 +2283,7 @@ photos_base_item_load_finish (PhotosBaseItem *self, GAsyncResult *res, GError **
 void
 photos_base_item_open (PhotosBaseItem *self, GdkScreen *screen, guint32 timestamp)
 {
+  g_return_if_fail (PHOTOS_IS_BASE_ITEM (self));
   PHOTOS_BASE_ITEM_GET_CLASS (self)->open (self, screen, timestamp);
 }
 
@@ -2192,10 +2291,16 @@ photos_base_item_open (PhotosBaseItem *self, GdkScreen *screen, guint32 timestam
 void
 photos_base_item_operation_add (PhotosBaseItem *self, const gchar *operation, const gchar *first_property_name, ...)
 {
+  PhotosBaseItemPrivate *priv;
   va_list ap;
 
+  g_return_if_fail (PHOTOS_IS_BASE_ITEM (self));
+  priv = self->priv;
+
+  g_return_if_fail (!priv->collection);
+
   va_start (ap, first_property_name);
-  photos_pipeline_add (self->priv->pipeline, operation, first_property_name, ap);
+  photos_pipeline_add (priv->pipeline, operation, first_property_name, ap);
   va_end (ap);
 }
 
@@ -2203,11 +2308,17 @@ photos_base_item_operation_add (PhotosBaseItem *self, const gchar *operation, co
 gboolean
 photos_base_item_operation_get (PhotosBaseItem *self, const gchar *operation, const gchar *first_property_name, ...)
 {
+  PhotosBaseItemPrivate *priv;
   gboolean ret_val;
   va_list ap;
 
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), FALSE);
+  priv = self->priv;
+
+  g_return_val_if_fail (!priv->collection, FALSE);
+
   va_start (ap, first_property_name);
-  ret_val = photos_pipeline_get (self->priv->pipeline, operation, first_property_name, ap);
+  ret_val = photos_pipeline_get (priv->pipeline, operation, first_property_name, ap);
   va_end (ap);
 
   return ret_val;
@@ -2217,14 +2328,28 @@ photos_base_item_operation_get (PhotosBaseItem *self, const gchar *operation, co
 gboolean
 photos_base_item_operation_remove (PhotosBaseItem *self, const gchar *operation)
 {
-  return photos_pipeline_remove (self->priv->pipeline, operation);
+  PhotosBaseItemPrivate *priv;
+
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), FALSE);
+  priv = self->priv;
+
+  g_return_val_if_fail (!priv->collection, FALSE);
+
+  return photos_pipeline_remove (priv->pipeline, operation);
 }
 
 
 void
 photos_base_item_operations_revert (PhotosBaseItem *self)
 {
-  return photos_pipeline_revert (self->priv->pipeline);
+  PhotosBaseItemPrivate *priv;
+
+  g_return_if_fail (PHOTOS_IS_BASE_ITEM (self));
+  priv = self->priv;
+
+  g_return_if_fail (!priv->collection);
+
+  photos_pipeline_revert (priv->pipeline);
 }
 
 
@@ -2240,6 +2365,7 @@ photos_base_item_pipeline_save_async (PhotosBaseItem *self,
   g_return_if_fail (PHOTOS_IS_BASE_ITEM (self));
   priv = self->priv;
 
+  g_return_if_fail (!priv->collection);
   g_return_if_fail (priv->edit_graph != NULL);
   g_return_if_fail (priv->load_graph != NULL);
   g_return_if_fail (priv->pipeline != NULL);
@@ -2261,6 +2387,7 @@ photos_base_item_pipeline_save_finish (PhotosBaseItem *self, GAsyncResult *res,
 {
   GTask *task = G_TASK (res);
 
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), FALSE);
   g_return_val_if_fail (g_task_is_valid (res, self), FALSE);
   g_return_val_if_fail (g_task_get_source_tag (task) == photos_base_item_pipeline_save_async, FALSE);
   g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
@@ -2272,13 +2399,23 @@ photos_base_item_pipeline_save_finish (PhotosBaseItem *self, GAsyncResult *res,
 void
 photos_base_item_pipeline_snapshot (PhotosBaseItem *self)
 {
-  return photos_pipeline_snapshot (self->priv->pipeline);
+  PhotosBaseItemPrivate *priv;
+
+  g_return_if_fail (PHOTOS_IS_BASE_ITEM (self));
+  priv = self->priv;
+
+  g_return_if_fail (!priv->collection);
+
+  photos_pipeline_snapshot (priv->pipeline);
 }
 
 
 void
 photos_base_item_print (PhotosBaseItem *self, GtkWidget *toplevel)
 {
+  g_return_if_fail (PHOTOS_IS_BASE_ITEM (self));
+  g_return_if_fail (!self->priv->collection);
+
   photos_base_item_load_async (self, NULL, photos_base_item_print_load, g_object_ref (toplevel));
 }
 
@@ -2295,6 +2432,8 @@ photos_base_item_process_async (PhotosBaseItem *self,
   g_return_if_fail (PHOTOS_IS_BASE_ITEM (self));
   priv = self->priv;
 
+  g_return_if_fail (!priv->collection);
+
   g_clear_object (&priv->processor);
   priv->processor = photos_pipeline_new_processor (priv->pipeline);
 
@@ -2312,6 +2451,7 @@ photos_base_item_process_finish (PhotosBaseItem *self, GAsyncResult *res, GError
 {
   GTask *task = G_TASK (res);
 
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), FALSE);
   g_return_val_if_fail (g_task_is_valid (res, self), FALSE);
   g_return_val_if_fail (g_task_get_source_tag (task) == photos_base_item_process_async, FALSE);
   g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
@@ -2327,6 +2467,8 @@ photos_base_item_refresh (PhotosBaseItem *self)
   PhotosSearchContextState *state;
   PhotosSingleItemJob *job;
 
+  g_return_if_fail (PHOTOS_IS_BASE_ITEM (self));
+
   app = g_application_get_default ();
   state = photos_search_context_get_state (PHOTOS_SEARCH_CONTEXT (app));
 
@@ -2358,6 +2500,7 @@ photos_base_item_save_async (PhotosBaseItem *self,
   g_return_if_fail (PHOTOS_IS_BASE_ITEM (self));
   priv = self->priv;
 
+  g_return_if_fail (!priv->collection);
   g_return_if_fail (G_IS_FILE (dir));
   g_return_if_fail (priv->edit_graph != NULL);
   g_return_if_fail (priv->filename != NULL && priv->filename[0] != '\0');
@@ -2395,6 +2538,7 @@ photos_base_item_save_finish (PhotosBaseItem *self, GAsyncResult *res, GError **
 {
   GTask *task = G_TASK (res);
 
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), FALSE);
   g_return_val_if_fail (g_task_is_valid (res, self), FALSE);
   g_return_val_if_fail (g_task_get_source_tag (task) == photos_base_item_save_async, FALSE);
   g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
@@ -2418,6 +2562,7 @@ photos_base_item_save_guess_sizes_async (PhotosBaseItem *self,
   g_return_if_fail (PHOTOS_IS_BASE_ITEM (self));
   priv = self->priv;
 
+  g_return_if_fail (!priv->collection);
   g_return_if_fail (priv->edit_graph != NULL);
   g_return_if_fail (priv->load_graph != NULL);
   g_return_if_fail (priv->pipeline != NULL);
@@ -2451,6 +2596,7 @@ photos_base_item_save_guess_sizes_finish (PhotosBaseItem *self,
   gboolean ret_val = FALSE;
   gsize *sizes;
 
+  g_return_val_if_fail (PHOTOS_IS_BASE_ITEM (self), FALSE);
   g_return_val_if_fail (g_task_is_valid (res, self), FALSE);
   g_return_val_if_fail (g_task_get_source_tag (task) == photos_base_item_save_guess_sizes_async, FALSE);
   g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
@@ -2474,9 +2620,12 @@ photos_base_item_save_guess_sizes_finish (PhotosBaseItem *self,
 void
 photos_base_item_set_default_app (PhotosBaseItem *self, GAppInfo *default_app)
 {
-  PhotosBaseItemPrivate *priv = self->priv;
+  PhotosBaseItemPrivate *priv;
   const gchar *default_app_name;
 
+  g_return_if_fail (PHOTOS_IS_BASE_ITEM (self));
+  priv = self->priv;
+
   if (priv->default_app == NULL && default_app == NULL)
     return;
 
@@ -2499,7 +2648,10 @@ photos_base_item_set_default_app (PhotosBaseItem *self, GAppInfo *default_app)
 void
 photos_base_item_set_default_app_name (PhotosBaseItem *self, const gchar *default_app_name)
 {
-  PhotosBaseItemPrivate *priv = self->priv;
+  PhotosBaseItemPrivate *priv;
+
+  g_return_if_fail (PHOTOS_IS_BASE_ITEM (self));
+  priv = self->priv;
 
   g_clear_object (&priv->default_app);
   g_free (priv->default_app_name);
@@ -2510,6 +2662,8 @@ photos_base_item_set_default_app_name (PhotosBaseItem *self, const gchar *defaul
 void
 photos_base_item_set_favorite (PhotosBaseItem *self, gboolean favorite)
 {
+  g_return_if_fail (PHOTOS_IS_BASE_ITEM (self));
+  g_return_if_fail (!self->priv->collection);
   PHOTOS_BASE_ITEM_GET_CLASS (self)->set_favorite (self, favorite);
 }
 
@@ -2519,9 +2673,11 @@ photos_base_item_trash (PhotosBaseItem *self)
 {
   PhotosDeleteItemJob *job;
 
+  g_return_if_fail (PHOTOS_IS_BASE_ITEM (self));
+
   PHOTOS_BASE_ITEM_GET_CLASS (self)->trash (self);
 
   job = photos_delete_item_job_new (self->priv->id);
-  photos_delete_item_job_run (job, NULL, NULL);
+  photos_delete_item_job_run (job, NULL, NULL, NULL);
   g_object_unref (job);
 }
