@@ -149,6 +149,7 @@ photos_delete_notification_constructed (GObject *object)
 
   label = gtk_label_new (msg);
   gtk_widget_set_halign (label, GTK_ALIGN_START);
+  gtk_widget_set_hexpand (label, TRUE);
   gtk_container_add (GTK_CONTAINER (self), label);
   g_free (msg);
 
@@ -173,11 +174,7 @@ photos_delete_notification_constructed (GObject *object)
   photos_notification_manager_add_notification (PHOTOS_NOTIFICATION_MANAGER (self->ntfctn_mngr),
                                                 GTK_WIDGET (self));
 
-  self->timeout_id = g_timeout_add_seconds_full (G_PRIORITY_DEFAULT,
-                                                 DELETE_TIMEOUT,
-                                                 photos_delete_notification_timeout,
-                                                 g_object_ref (self),
-                                                 g_object_unref);
+  self->timeout_id = g_timeout_add_seconds (DELETE_TIMEOUT, photos_delete_notification_timeout, self);
 }
 
 
@@ -186,6 +183,8 @@ photos_delete_notification_dispose (GObject *object)
 {
   PhotosDeleteNotification *self = PHOTOS_DELETE_NOTIFICATION (object);
 
+  photos_delete_notification_remove_timeout (self);
+
   g_list_free_full (self->items, g_object_unref);
   self->items = NULL;
 
@@ -228,7 +227,7 @@ photos_delete_notification_init (PhotosDeleteNotification *self)
   app = g_application_get_default ();
   state = photos_search_context_get_state (PHOTOS_SEARCH_CONTEXT (app));
 
-  self->ntfctn_mngr = g_object_ref_sink (photos_notification_manager_dup_singleton ());
+  self->ntfctn_mngr = photos_notification_manager_dup_singleton ();
   self->item_mngr = g_object_ref (state->item_mngr);
 }
 
