@@ -35,8 +35,9 @@
 #include "photos-search-context.h"
 
 
-struct _PhotosDropdownPrivate
+struct _PhotosDropdown
 {
+  GtkPopover parent_instance;
   GList *models;
   GtkWidget *grid;
   GtkWidget *match_view;
@@ -47,21 +48,25 @@ struct _PhotosDropdownPrivate
   PhotosBaseManager *src_mngr;
 };
 
+struct _PhotosDropdownClass
+{
+  GtkPopoverClass parent_class;
+};
 
-G_DEFINE_TYPE_WITH_PRIVATE (PhotosDropdown, photos_dropdown, GTK_TYPE_POPOVER);
+
+G_DEFINE_TYPE (PhotosDropdown, photos_dropdown, GTK_TYPE_POPOVER);
 
 
 static void
 photos_dropdown_add_manager (PhotosDropdown *self, PhotosBaseManager *mngr)
 {
-  PhotosDropdownPrivate *priv = self->priv;
   GMenu *menu;
   GtkWidget *popover;
   GtkWidget *w;
   PhotosBaseModel *model;
 
   model = photos_base_model_new (mngr);
-  priv->models = g_list_prepend (priv->models, g_object_ref (model));
+  self->models = g_list_prepend (self->models, g_object_ref (model));
 
   /* HACK: see https://bugzilla.gnome.org/show_bug.cgi?id=733977 */
   popover = gtk_popover_new (NULL);
@@ -69,7 +74,7 @@ photos_dropdown_add_manager (PhotosDropdown *self, PhotosBaseManager *mngr)
   gtk_popover_bind_model (GTK_POPOVER (popover), G_MENU_MODEL (menu), "app");
   w = g_object_ref (gtk_bin_get_child (GTK_BIN (popover)));
   gtk_container_remove (GTK_CONTAINER (popover), w);
-  gtk_container_add (GTK_CONTAINER (self->priv->grid), w);
+  gtk_container_add (GTK_CONTAINER (self->grid), w);
   g_object_unref (w);
   gtk_widget_set_valign (w, GTK_ALIGN_START);
   gtk_widget_set_vexpand (w, TRUE);
@@ -83,14 +88,13 @@ static void
 photos_dropdown_dispose (GObject *object)
 {
   PhotosDropdown *self = PHOTOS_DROPDOWN (object);
-  PhotosDropdownPrivate *priv = self->priv;
 
-  g_clear_object (&priv->srch_mtch_mngr);
-  g_clear_object (&priv->srch_typ_mngr);
-  g_clear_object (&priv->src_mngr);
+  g_clear_object (&self->srch_mtch_mngr);
+  g_clear_object (&self->srch_typ_mngr);
+  g_clear_object (&self->src_mngr);
 
-  g_list_free_full (priv->models, g_object_unref);
-  priv->models = NULL;
+  g_list_free_full (self->models, g_object_unref);
+  self->models = NULL;
 
   G_OBJECT_CLASS (photos_dropdown_parent_class)->dispose (object);
 }
@@ -99,34 +103,30 @@ photos_dropdown_dispose (GObject *object)
 static void
 photos_dropdown_init (PhotosDropdown *self)
 {
-  PhotosDropdownPrivate *priv;
   GApplication *app;
   GtkStyleContext *context;
   PhotosSearchContextState *state;
 
-  self->priv = photos_dropdown_get_instance_private (self);
-  priv = self->priv;
-
   app = g_application_get_default ();
   state = photos_search_context_get_state (PHOTOS_SEARCH_CONTEXT (app));
 
-  priv->srch_mtch_mngr = g_object_ref (state->srch_mtch_mngr);
-  priv->srch_typ_mngr = g_object_ref (state->srch_typ_mngr);
-  priv->src_mngr = g_object_ref (state->src_mngr);
+  self->srch_mtch_mngr = g_object_ref (state->srch_mtch_mngr);
+  self->srch_typ_mngr = g_object_ref (state->srch_typ_mngr);
+  self->src_mngr = g_object_ref (state->src_mngr);
 
-  priv->grid = gtk_grid_new ();
-  gtk_orientable_set_orientation (GTK_ORIENTABLE (priv->grid), GTK_ORIENTATION_HORIZONTAL);
-  gtk_grid_set_row_homogeneous (GTK_GRID (priv->grid), TRUE);
-  gtk_container_add (GTK_CONTAINER (self), priv->grid);
+  self->grid = gtk_grid_new ();
+  gtk_orientable_set_orientation (GTK_ORIENTABLE (self->grid), GTK_ORIENTATION_HORIZONTAL);
+  gtk_grid_set_row_homogeneous (GTK_GRID (self->grid), TRUE);
+  gtk_container_add (GTK_CONTAINER (self), self->grid);
 
-  photos_dropdown_add_manager (self, priv->src_mngr);
-  photos_dropdown_add_manager (self, priv->srch_typ_mngr);
-  photos_dropdown_add_manager (self, priv->srch_mtch_mngr);
+  photos_dropdown_add_manager (self, self->src_mngr);
+  photos_dropdown_add_manager (self, self->srch_typ_mngr);
+  photos_dropdown_add_manager (self, self->srch_mtch_mngr);
 
   context = gtk_widget_get_style_context (GTK_WIDGET (self));
   gtk_style_context_add_class (context, "photos-dropdown");
   gtk_widget_hide (GTK_WIDGET(self));
-  gtk_widget_show_all (GTK_WIDGET (priv->grid));
+  gtk_widget_show_all (GTK_WIDGET (self->grid));
 }
 
 
