@@ -48,6 +48,7 @@
 #include "photos-tracker-overview-controller.h"
 #include "photos-utils.h"
 #include "photos-view-container.h"
+#include "photos-view-model.h"
 
 
 typedef struct _PhotosEmbedSearchState PhotosEmbedSearchState;
@@ -175,12 +176,25 @@ photos_embed_get_view_container_from_mode (PhotosEmbed *self, PhotosWindowMode m
 static void
 photos_embed_activate_result (PhotosEmbed *self)
 {
+  GtkTreeIter iter;
+  GtkListStore *store;
   GtkWidget *view_container;
   PhotosWindowMode mode;
 
   mode = photos_mode_controller_get_window_mode (self->mode_cntrlr);
   view_container = photos_embed_get_view_container_from_mode (self, mode);
-  photos_view_container_activate_result (PHOTOS_VIEW_CONTAINER (view_container));
+  store = photos_view_container_get_model (PHOTOS_VIEW_CONTAINER (view_container));
+
+  if (gtk_tree_model_get_iter_first (GTK_TREE_MODEL (store), &iter))
+    {
+      GObject *item;
+      gchar *id;
+
+      gtk_tree_model_get (GTK_TREE_MODEL (store), &iter, PHOTOS_VIEW_MODEL_URN, &id, -1);
+      item = photos_base_manager_get_object_by_id (self->item_mngr, id);
+      photos_base_manager_set_active_object (self->item_mngr, item);
+      g_free (id);
+    }
 }
 
 
@@ -329,7 +343,6 @@ photos_embed_load_show_timeout (gpointer user_data)
 
   self->load_show_id = 0;
   photos_spinner_box_start (PHOTOS_SPINNER_BOX (self->spinner_box));
-  g_object_unref (self);
   return G_SOURCE_REMOVE;
 }
 
@@ -338,7 +351,7 @@ static void
 photos_embed_load_started (PhotosEmbed *self, PhotosBaseItem *item)
 {
   photos_embed_clear_load_timer (self);
-  self->load_show_id = g_timeout_add (400, photos_embed_load_show_timeout, g_object_ref (self));
+  self->load_show_id = g_timeout_add (400, photos_embed_load_show_timeout, self);
 }
 
 
@@ -597,6 +610,7 @@ photos_embed_dispose (GObject *object)
 {
   PhotosEmbed *self = PHOTOS_EMBED (object);
 
+  photos_embed_clear_load_timer (self);
   photos_embed_clear_search (self);
 
   g_clear_object (&self->ntfctn_mngr);
@@ -665,7 +679,7 @@ photos_embed_init (PhotosEmbed *self)
   searchbar = photos_main_toolbar_get_searchbar (PHOTOS_MAIN_TOOLBAR (self->toolbar));
   g_signal_connect_swapped (searchbar, "activate-result", G_CALLBACK (photos_embed_activate_result), self);
 
-  self->ntfctn_mngr = g_object_ref_sink (photos_notification_manager_dup_singleton ());
+  self->ntfctn_mngr = photos_notification_manager_dup_singleton ();
   gtk_overlay_add_overlay (GTK_OVERLAY (self->stack_overlay), self->ntfctn_mngr);
 
   self->overview = photos_view_container_new (PHOTOS_WINDOW_MODE_OVERVIEW, _("Photos"));
