@@ -214,11 +214,7 @@ photos_indexing_notification_check_notification (PhotosIndexingNotification *sel
   else if (is_indexing_remote)
     {
       photos_indexing_notification_remove_timeout (self);
-      self->timeout_id = g_timeout_add_seconds_full (G_PRIORITY_DEFAULT,
-                                                     REMOTE_MINER_TIMEOUT,
-                                                     photos_indexing_notification_timeout,
-                                                     g_object_ref (self),
-                                                     g_object_unref);
+      self->timeout_id = g_timeout_add_seconds (REMOTE_MINER_TIMEOUT, photos_indexing_notification_timeout, self);
     }
   else
     photos_indexing_notification_destroy (self, FALSE);
@@ -233,6 +229,8 @@ photos_indexing_notification_dispose (GObject *object)
 {
   PhotosIndexingNotification *self = PHOTOS_INDEXING_NOTIFICATION (object);
 
+  photos_indexing_notification_remove_timeout (self);
+
   g_clear_object (&self->ntfctn_mngr);
   g_clear_object (&self->manager);
 
@@ -262,7 +260,7 @@ photos_indexing_notification_init (PhotosIndexingNotification *self)
       return;
     }
 
-  self->ntfctn_mngr = g_object_ref_sink (photos_notification_manager_dup_singleton ());
+  self->ntfctn_mngr = photos_notification_manager_dup_singleton ();
 
   self->spinner = gtk_spinner_new ();
   gtk_widget_set_size_request (self->spinner, 16, 16);
@@ -275,10 +273,12 @@ photos_indexing_notification_init (PhotosIndexingNotification *self)
 
   self->primary_label = gtk_label_new (NULL);
   gtk_widget_set_halign (self->primary_label, GTK_ALIGN_START);
+  gtk_widget_set_hexpand (self->primary_label, TRUE);
   gtk_container_add (GTK_CONTAINER (labels), self->primary_label);
 
   self->secondary_label = gtk_label_new (NULL);
   gtk_widget_set_halign (self->secondary_label, GTK_ALIGN_START);
+  gtk_widget_set_hexpand (self->secondary_label, TRUE);
   context = gtk_widget_get_style_context (self->secondary_label);
   gtk_style_context_add_class (context, "dim-label");
   gtk_container_add (GTK_CONTAINER (labels), self->secondary_label);
