@@ -74,15 +74,6 @@ enum
   PROP_PREVIEW_VIEW
 };
 
-enum
-{
-  LOAD_NEXT,
-  LOAD_PREVIOUS,
-  LAST_SIGNAL
-};
-
-static guint signals[LAST_SIGNAL] = { 0 };
-
 
 G_DEFINE_TYPE (PhotosPreviewNavButtons, photos_preview_nav_buttons, G_TYPE_OBJECT);
 
@@ -228,11 +219,7 @@ static void
 photos_preview_nav_buttons_queue_auto_hide (PhotosPreviewNavButtons *self)
 {
   photos_preview_nav_buttons_unqueue_auto_hide (self);
-  self->auto_hide_id = g_timeout_add_seconds_full (G_PRIORITY_DEFAULT,
-                                                   2,
-                                                   (GSourceFunc) photos_preview_nav_buttons_auto_hide,
-                                                   g_object_ref (self),
-                                                   g_object_unref);
+  self->auto_hide_id = g_timeout_add_seconds (2, (GSourceFunc) photos_preview_nav_buttons_auto_hide, self);
 }
 
 
@@ -335,8 +322,6 @@ photos_preview_nav_buttons_next (PhotosPreviewNavButtons *self)
   if (!self->enable_next)
     return;
 
-  g_signal_emit (self, signals[LOAD_NEXT], 0);
-
   current_path = gtk_tree_row_reference_get_path (self->current_row);
   gtk_tree_path_next (current_path);
   photos_preview_nav_buttons_set_active_path (self, current_path);
@@ -353,8 +338,6 @@ photos_preview_nav_buttons_previous (PhotosPreviewNavButtons *self)
   if (!self->enable_prev)
     return;
 
-  g_signal_emit (self, signals[LOAD_PREVIOUS], 0);
-
   current_path = gtk_tree_row_reference_get_path (self->current_row);
   gtk_tree_path_prev (current_path);
   photos_preview_nav_buttons_set_active_path (self, current_path);
@@ -368,6 +351,8 @@ photos_preview_nav_buttons_dispose (GObject *object)
 {
   PhotosPreviewNavButtons *self = PHOTOS_PREVIEW_NAV_BUTTONS (object);
 
+  photos_preview_nav_buttons_unqueue_auto_hide (self);
+
   g_clear_object (&self->tap_gesture);
   g_clear_object (&self->model);
   g_clear_object (&self->next_widget);
@@ -557,26 +542,6 @@ photos_preview_nav_buttons_class_init (PhotosPreviewNavButtonsClass *class)
                                                         "The widget used for showing the preview",
                                                         PHOTOS_TYPE_PREVIEW_VIEW,
                                                         G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE));
-
-  signals[LOAD_NEXT] = g_signal_new ("load-next",
-                                     G_TYPE_FROM_CLASS (class),
-                                     G_SIGNAL_RUN_LAST,
-                                     0,
-                                     NULL, /*accumulator */
-                                     NULL, /*accu_data */
-                                     g_cclosure_marshal_VOID__VOID,
-                                     G_TYPE_NONE,
-                                     0);
-
-  signals[LOAD_PREVIOUS] = g_signal_new ("load-previous",
-                                         G_TYPE_FROM_CLASS (class),
-                                         G_SIGNAL_RUN_LAST,
-                                         0,
-                                         NULL, /*accumulator */
-                                         NULL, /*accu_data */
-                                         g_cclosure_marshal_VOID__VOID,
-                                         G_TYPE_NONE,
-                                         0);
 }
 
 
